@@ -142,24 +142,24 @@
      TK_SIPSLOTCON = 358,
      TK_SIPSLOTDIS = 359,
      TK_SIPSSIZET = 360,
-     TK_NUMBER_VALUE = 361,
-     TK_REAL_VALUE = 362,
-     TK_TYPEDEF = 363,
-     TK_NAMESPACE = 364,
-     TK_TIMELINE = 365,
-     TK_PLATFORMS = 366,
-     TK_FEATURE = 367,
-     TK_LICENSE = 368,
-     TK_QCHAR_VALUE = 369,
-     TK_TRUE_VALUE = 370,
-     TK_FALSE_VALUE = 371,
-     TK_NULL_VALUE = 372,
-     TK_OPERATOR = 373,
-     TK_THROW = 374,
-     TK_QOBJECT = 375,
-     TK_EXCEPTION = 376,
-     TK_RAISECODE = 377,
-     TK_VIRTERRORCODE = 378,
+     TK_SIZET = 361,
+     TK_NUMBER_VALUE = 362,
+     TK_REAL_VALUE = 363,
+     TK_TYPEDEF = 364,
+     TK_NAMESPACE = 365,
+     TK_TIMELINE = 366,
+     TK_PLATFORMS = 367,
+     TK_FEATURE = 368,
+     TK_LICENSE = 369,
+     TK_QCHAR_VALUE = 370,
+     TK_TRUE_VALUE = 371,
+     TK_FALSE_VALUE = 372,
+     TK_NULL_VALUE = 373,
+     TK_OPERATOR = 374,
+     TK_THROW = 375,
+     TK_QOBJECT = 376,
+     TK_EXCEPTION = 377,
+     TK_RAISECODE = 378,
      TK_EXPLICIT = 379,
      TK_TEMPLATE = 380,
      TK_FINAL = 381,
@@ -294,24 +294,24 @@
 #define TK_SIPSLOTCON 358
 #define TK_SIPSLOTDIS 359
 #define TK_SIPSSIZET 360
-#define TK_NUMBER_VALUE 361
-#define TK_REAL_VALUE 362
-#define TK_TYPEDEF 363
-#define TK_NAMESPACE 364
-#define TK_TIMELINE 365
-#define TK_PLATFORMS 366
-#define TK_FEATURE 367
-#define TK_LICENSE 368
-#define TK_QCHAR_VALUE 369
-#define TK_TRUE_VALUE 370
-#define TK_FALSE_VALUE 371
-#define TK_NULL_VALUE 372
-#define TK_OPERATOR 373
-#define TK_THROW 374
-#define TK_QOBJECT 375
-#define TK_EXCEPTION 376
-#define TK_RAISECODE 377
-#define TK_VIRTERRORCODE 378
+#define TK_SIZET 361
+#define TK_NUMBER_VALUE 362
+#define TK_REAL_VALUE 363
+#define TK_TYPEDEF 364
+#define TK_NAMESPACE 365
+#define TK_TIMELINE 366
+#define TK_PLATFORMS 367
+#define TK_FEATURE 368
+#define TK_LICENSE 369
+#define TK_QCHAR_VALUE 370
+#define TK_TRUE_VALUE 371
+#define TK_FALSE_VALUE 372
+#define TK_NULL_VALUE 373
+#define TK_OPERATOR 374
+#define TK_THROW 375
+#define TK_QOBJECT 376
+#define TK_EXCEPTION 377
+#define TK_RAISECODE 378
 #define TK_EXPLICIT 379
 #define TK_TEMPLATE 380
 #define TK_FINAL 381
@@ -346,7 +346,7 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 202 "sip-4.19.13/sipgen/metasrc/parser.y"
+#line 202 "sip-4.19.14/sipgen/metasrc/parser.y"
 {
     char            qchar;
     char            *text;
@@ -392,7 +392,7 @@ typedef union YYSTYPE
     int             token;
 }
 /* Line 1529 of yacc.c.  */
-#line 396 "sip-4.19.13/sipgen/parser.h"
+#line 396 "sip-4.19.14/sipgen/parser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
